@@ -7,7 +7,7 @@ Usage (cli):
 
     $ ss | jc --ss
 
-    or
+or
 
     $ jc ss
 
@@ -281,7 +281,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.5'
+    version = '1.6'
     description = '`ss` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -304,8 +304,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'recv_q', 'send_q', 'pid'}
+
     for entry in proc_data:
-        int_list = ['recv_q', 'send_q', 'pid']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
